@@ -43,6 +43,11 @@ try:
 except ImportError:
     from pysqlite2 import dbapi2 as sqlite3
 
+# for pypy, since the sqlite3 package is empty... but they have a pysqlite2.
+if not hasattr(sqlite3, "register_converter"):
+    from pysqlite2 import dbapi2 as sqlite3
+
+
 try:
     import cPickle as pickle
 except ImportError:
@@ -55,9 +60,18 @@ except ImportError:
     import collections
     UserDict = collections.UserDict
 
+
 serialiser = pickle
 sqlite3.register_converter("pickle", serialiser.loads)
 
+#sqlite3.PARSE_DECLTYPES = 1
+#sqlite3.PARSE_COLNAMES = 2
+
+
+def deserialise(data):
+    return data
+    #return serialiser.loads(str(data))
+
 
 class SQLPickle(object):
 
@@ -121,21 +135,22 @@ class SQLPickle(object):
         arow = self._cursor.execute(q, (key,)).fetchone()
         if arow is None:
             return default
-        return arow['value']
+        return deserialise( arow['value'] )
 
     def keys(self):
         """ keys() returns a generator of keys.
         """
         q = "select key from %s" % self._table_name
         rows = self._cursor.execute(q).fetchall()
-        return (row['key'] for row in rows)
+        #return (deserialise(row['key']) for row in rows)
+        return [deserialise(row['key']) for row in rows]
 
     def items(self):
         """ items() returns a generator of (key,value) pairs.
         """
         q = "select * from %s" % self._table_name
         rows = self._cursor.execute(q).fetchall()
-        return ((row['key'], row['value']) for row in rows)
+        return ((deserialise(row['key']), deserialise(row['value'])) for row in rows)
 
 
 
